# EveSSO

SSO Authorization for Eve Online.

## About

This library implements the native SSO authorization flow as described [here](https://docs.esi.evetech.net/docs/sso/native_sso_flow.html). EveSSO will perform the authorization process as needed, store your access and refresh tokens, and refresh your access token as needed. It will then provide the required header for your requests.

## Installation

```
pip install evesso
```

## Quickstart

```
from evesso import SSO
import requests

sso = SSO(
    client_id='1234567890asdfghjklqwertyuiop',
    callback_url='http://localhost/',
    scope='esi-characters.some_scope.v1 esi-characters.some_scope.v1'
)
response = requests.get(
    'https://esi.evetech.net/latest/markets/structures/SOME_STRUCTURE_ID/?datasource=tranquility',
    headers=sso.get_header()
)
response.raise_for_status()
print(response.json())
```

### Using .env file

```
CLIENT_ID = 1234567890asdfghjklqwertyuiop
CALLBACK_URL = http://localhost/
SCOPE = esi-characters.some_scope.v1 esi-characters.some_scope.v1
```

Esi will check environment variables for credentials if not parameterized.

```
from evesso import SSO
from dotenv import load_dotenv
import requests

load_dotenv()

sso = SSO()
response = requests.get(
    'https://esi.evetech.net/latest/markets/structures/SOME_STRUCTURE_ID/?datasource=tranquility',
    headers=sso.get_header()
)
response.raise_for_status()
print(response.json())
```

## Authorizing on a remote machine

1. Set the `cli` parameter to `True`.
2. The auth url will be printed to the command line.
3. Open the auth url in a browser and complete the auth process
4. The SSO server will make a get request to the machine where you opened the auth url
5. Copy the callback url and paste it into the command line so evesso can parse it

```
from evesso import SSO

sso = SSO(cli=True)
...
```